import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import moment from 'moment';
import classnames from 'classnames';
import queryString from 'query-string';
import { Divider, Modal, Table, Menu, Icon, Badge } from 'antd';
import AnimTableBody from '../../../components/Animation/AnimTableBody';
import { itemStatuses, Codes, productType } from '../../../utils/config';
import styles from './table.less';

const confirm = Modal.confirm;

export default class TableList extends PureComponent {
  static propTypes = {
    location: PropTypes.object,
    onChange: PropTypes.func.isRequired,
    onDeleteItem: PropTypes.func.isRequired,
    onEditItem: PropTypes.func.isRequired,
  };

  handleOperateItem = (record) => {
    const { onDeleteItem, onRecoverItem } = this.props;
    confirm({
      title: `您确定要${record.status === Codes.CODE_NORMAL ? '下架' : '出售'}该产品?`,
      onOk () {
        if (record.status === Codes.CODE_NORMAL) {
          onDeleteItem({ pid: record.pid, merchantId: record.merchantId, status: Codes.CODE_DELETE });
        } else if (record.status === Codes.CODE_DELETE) {
          onRecoverItem({ pid: record.pid, merchantId: record.merchantId, status: Codes.CODE_NORMAL });
        }
      },
    })
  }

  render() {
    const {
      curStatus,
      curMid,
      onDeleteItem,
      onRecoverItem,
      onEditItem,
      location,
      pagination,
      merchantList,
      ...tableProps
    } = this.props;
    const columns = [{
      title: '产品编号',
      dataIndex: 'code',
      key: 'code',
    },{
      title: '产品名称',
      dataIndex: 'name',
      key: 'name',
    },{
      title: '产品类型',
      dataIndex: 'type',
      key: 'type',
      render: (text, record) => productType[record.type],
    },{
      title: '渠道名称',
      dataIndex: 'merchantId',
      key: 'merchantId',
      render: (text, record) => record.merchantName,
      filters: merchantList.map(item => ({ text: item.name, value: item.id })),
      filterMultiple: false,
      filteredValue: [curMid],
    },{
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      render: (text, record) => {
        const statusMap = {[Codes.CODE_NORMAL]: 'success', [Codes.CODE_DELETE]: 'error'};
        return (<Badge status={statusMap[record.status]} text={itemStatuses[record.status]} />);
      },
      filters: Object.keys(itemStatuses).map(key => ({ text: itemStatuses[key], value: key })),
      filterMultiple: false,
      filteredValue: [curStatus],
    },{
      title: '创建时间',
      dataIndex: 'gmtModified',
      key: 'gmtModified',
      render: (text, record) => (
        <div>{moment(text).format('YYYY-MM-DD HH:mm:ss')}</div>
      )
    },{
      title: '操作',
      dataIndex: 'operation',
      key: 'operation',
      render: (text, record) => (
        <div>
          <a onClick={() => onEditItem(record)}>编辑</a>
          <Divider type="vertical" />
          <a onClick={() => this.handleOperateItem(record)}>{record.status === Codes.CODE_NORMAL ? '下架' : '出售'}</a>
        </div>
      )
    }];

    // 数据table列表表头的筛选按钮点击重置后status与merchantName值为空，此时删除该参数
    columns.map(item => {
      item.dataIndex === 'status' && !curStatus ? delete item.filteredValue : null;
      item.dataIndex === 'merchantId' && !curMid ? delete item.filteredValue : null;
    });

    // 覆盖表格的默认样式，添加动画
    tableProps.pagination = !!pagination && { ...pagination, showSizeChanger: true, showQuickJumper: true, showTotal: total => `共 ${total} 条`};
    const getBodyWrapperProps = {
      page: location.query.page,
      current: tableProps.pagination.current,
    };
    const getBodyWrapper = (body) => (<AnimTableBody {...getBodyWrapperProps} body={body} />);

    return (
      <Table
        simple
        bordered
        { ...tableProps }
        columns={columns}
        className={classnames({ [styles.table]: true, [styles.motion]: true })}
        rowKey={record => record.id}
        getBodyWrapper={getBodyWrapper}
      />
    );
  }
}
